import struct
from ..publisher import AirPublisher
from . import WeatherParser

class AirProParser(WeatherParser.WeatherParser):

	PRESSURE_HISTORY = {}

	def __init__(self, deltaEncoding=False, withVoltage=False):
		super().__init__(deltaEncoding, withVoltage, 8)

	def parse(self, txUID, msg):
		parsed = super().parse(txUID, msg)

		if self.deltaEncoding:
			pressureDelta = struct.unpack(">b", msg[3:4])[0] #signed 1 byte integer

			if txUID in self.PRESSURE_HISTORY:
				pressure = self.PRESSURE_HISTORY[txUID] + pressureDelta
			else:
				return parsed
		else:
			pressure = (msg[5] << 16) | (msg[6] << 8) | (msg[7])


		parsed['barometric_pressure'] = pressure
		self.PRESSURE_HISTORY[txUID] = pressure

		return parsed

	def getPublisher(self, mqttClient):
		return AirPublisher.AirPublisher(mqttClient)
